ricecooker package
==================

ricecooker.chefs module
-----------------------

.. automodule:: ricecooker.chefs

ricecooker.classes module
-------------------------

.. automodule:: ricecooker.classes.files
.. automodule:: ricecooker.classes.nodes
.. automodule:: ricecooker.classes.licenses
.. automodule:: ricecooker.classes.questions

ricecooker.commands module
--------------------------

.. automodule:: ricecooker.commands

ricecooker.config module
------------------------

.. automodule:: ricecooker.config

ricecooker.exceptions module
----------------------------

.. automodule:: ricecooker.exceptions

ricecooker.managers module
--------------------------

.. automodule:: ricecooker.managers
.. automodule:: ricecooker.managers.progress
.. automodule:: ricecooker.managers.tree

ricecooker.sushi\_bar\_client module
------------------------------------

.. automodule:: ricecooker.sushi_bar_client

ricecooker.utils module
-----------------------

There is :doc:`separate documentation <utils>` for the utilities.

Module contents
---------------

.. automodule:: ricecooker
